from tcsoa.gen.Internal_UiConfig._2014_11.services import UiConfigService as imp0
from tcsoa.base import TcService


class UiConfigService(TcService):
    resetUIConfigs = imp0.resetUIConfigs
